.. _dev-kit-API-reply:

microspeclib.datatypes.sensor module (dev-kit API responses)
============================================================

.. automodule:: microspeclib.datatypes.sensor
   :members:
   :undoc-members:
   :exclude-members: command_id, name, const, variables, sizes, repeat
